<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation>&lt;p&gt;Este serviço é inteiramente financiado por doações de pessoas como você. &lt;a href=&quot;%1&quot;&gt;Por favor, faça uma doação&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="103"/>
        <source>%1 version: 
%2</source>
        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation>%1 versão:
$2</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="180"/>
        <source>Recommended</source>
        <translation>Recomendado</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation>Resolução de problemas e suporte</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation>Reportar um bug</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation>Como desinstalar</translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation>Não foi possível encontrar &quot;helpers&quot;. Por favor, verifique sua instalação</translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation>Não foi possível encontrar um agente polkit.</translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation>Selecione um Local</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation>Use a melhor conexão automaticamente</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation>Selecionar manualmente</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation>Trocando gateway...</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation>Apenas locais com bridges</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation>Recomendado</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="43"/>
        <location filename="../components/MainView.qml" line="66"/>
        <source>Donate</source>
        <translation>Fazer uma doação</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="59"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="73"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="80"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="87"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="111"/>
        <source>Please donate!</source>
        <translation>Por favor, faça uma doação!</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="125"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation>Este serviço é inteiramente financiado por doações de pessoas como você. O custo de rodar uma VPN é de aproximadamente 5 USD por pessoa todo mês, mas qualquer coisinha ajuda. Você quer doar agora?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="11"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="55"/>
        <source>Turn off the VPN to make changes</source>
        <translation>Desligue a VPN para fazer alterações</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="71"/>
        <source>Language</source>
        <translation>Linguagem</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="105"/>
        <source>Censorship circumvention</source>
        <translation>Driblando a censura</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="113"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation>Estas técnicas podem driblar censura, mas são mais lentas. Use-as somente quando necessário.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="127"/>
        <source>Use obfs4 bridges</source>
        <translation>Usar bridges obfs4</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="153"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation>O tráfego é ofuscado para atravessar bloqueios</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="167"/>
        <source>Use Snowflake</source>
        <translation>Usar Snowflake</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="182"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation>Snowflake precisa do Tor instalado no seu sistema</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="213"/>
        <source>Obfs4 with KCP can help to bypass blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="227"/>
        <source>Transport</source>
        <translation>Transporte</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="235"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation>UDP pode tornar a VPN mais rápida. Mas pode ser bloqueado em algumas redes.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="248"/>
        <source>Use UDP if available</source>
        <translation>Usar UDP se possível</translation>
    </message>
    <message>
        <source>KCP might work when UDP is blocked on some networks.</source>
        <translation type="vanished">O KCP pode funcionar quando o UDP está bloqueado em algumas redes.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="196"/>
        <source>Use KCP if available</source>
        <translation>Use o KCP, se disponível</translation>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>There is a newer version available. </source>
        <translation>Há uma nova versão disponível.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation>Tenha certeza de &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;desinstalar&lt;/a&gt; a versão anterior antes de executar o novo instalador.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="105"/>
        <source>UPGRADE NOW</source>
        <translation>ATUALIZE AGORA</translation>
    </message>
</context>
<context>
    <name>StatusBox</name>
    <message>
        <location filename="../components/StatusBox.qml" line="78"/>
        <source>This can take several minutes</source>
        <translation>Isto pode demorar vários minutos</translation>
    </message>
    <message>
        <location filename="../components/StatusBox.qml" line="149"/>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation>Verificando o estado...</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation>Fazer uma doação</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation>Esconder</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits the application</extracomment>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect to</source>
        <translation>Conectar a</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="76"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="79"/>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="26"/>
        <source>Setting up</source>
        <translation>Configurando</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="51"/>
        <location filename="../components/VPNState.qml" line="155"/>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="82"/>
        <source>Unsecured
Connection</source>
        <translation>Conexão
Insegura</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="98"/>
        <source>Turn on</source>
        <translation>Ligar</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="118"/>
        <source>Secured
Connection</source>
        <translation>Conexão
Segura</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="134"/>
        <source>Turn off</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="172"/>
        <location filename="../components/VPNState.qml" line="211"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="269"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 desligado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="269"/>
        <source>off</source>
        <translation>desligado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="272"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 ligado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="275"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Conectando a %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="278"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Parando %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="281"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 bloqueando Internet</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="288"/>
        <source>pluggable transport connection</source>
        <translation>conexão de transporte plugável</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="290"/>
        <source>connection done</source>
        <translation>conexão terminada</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="292"/>
        <source>doing handshake</source>
        <translation>fazendo handshake</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="294"/>
        <source>handshake done</source>
        <translation>handshake terminado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="296"/>
        <source>creating one-hop connection</source>
        <translation>criando conexão de um estágio</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="298"/>
        <source>requesting status</source>
        <translation>solicitando estado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="300"/>
        <source>loading status</source>
        <translation>carregando estado</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="302"/>
        <source>loading keys</source>
        <translation>carregando chaves</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="304"/>
        <source>requesting descriptors</source>
        <translation>requisitando descritores</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="306"/>
        <source>loading descriptors</source>
        <translation>carregando descritores</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="308"/>
        <source>creating circuit</source>
        <translation>criando circuito</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="310"/>
        <source>done</source>
        <translation>pronto</translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="167"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation>: uma VPN rápida e segura. Baseada em Bitmask.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="174"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation>Não mostrar ícone na bandeja (útil para uso conjunto com a extensão para Gnome Shell, ou para controlar a VPN por outros meios).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="181"/>
        <source>Enable Web API.</source>
        <translation>Habilitar API Web.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="187"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation>Instalar arquivos auxiliares (somente para Linux, requer sudo).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="193"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation>Usar obfs4 para ofuscar o tráfego, caso esteja disponível no provedor.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="199"/>
        <source>Enable autostart.</source>
        <translation>Habilitar auto inicialização.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="204"/>
        <source>Web API port (default: 8080)</source>
        <translation>Porta para API Web (padrão: 8080)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="207"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation>Iniciar VPN, pode ser &apos;ligado&apos; ou &apos;desligado&apos;.</translation>
    </message>
</context>
</TS>
